int myrand(int max);
void * mymalloc(int size, char *what);
void * myrealloc(void *oldp, int newsize, char *what);
void myfree(void *p);
char * mystrdup(char *in, char *what);
char * read_line_fd(int fd);
char * get_load(void);
int get_vmsize(pid_t pid);
void stop_process(int pid);
void delete_array(char **list, int n);
int find_char_offset(char *str, char what);
int file_info(char *filename, off_t *file_size, time_t *ts);
char * convert_regexp_error(int error, const regex_t *preg);
char check_date(void);
ssize_t WRITE(int fd, char *whereto, size_t len);
char * amount_to_str(int amount);
char * replace_string(char *in, int pos_start, int pos_end, char *with_what);
struct passwd *getuserinfo(void);
int myopen(char *path, int mode);
int myclose(int fd);

#define min(x, y) ((x)<(y)?(x):(y))
#define max(x, y) ((x)>(y)?(x):(y))
